@@ -1,6 +1,5 @@
-# -*- coding: utf-8 -*-
 from plone.registry.interfaces import IRegistry
-from Products.CMFPlone.interfaces import ISiteSchema
+from plone.base.interfaces import ISiteSchema
 from Products.Five.browser import BrowserView
 from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
 from zope.component import getUtility
@@ -14,7 +13,7 @@ class AnalyticsViewlet(BrowserView):
     render = ViewPageTemplateFile("view.pt")
 
     def __init__(self, context, request, view, manager):
-        super(AnalyticsViewlet, self).__init__(context, request)
+        super().__init__(context, request)
         self.__parent__ = view
         self.view = view
         self.manager = manager
@@ -24,11 +23,10 @@ class AnalyticsViewlet(BrowserView):
         registry = getUtility(IRegistry)
         site_settings = registry.forInterface(ISiteSchema, prefix="plone", check=False)
         try:
-            return site_settings.webstats_js or u""
+            return site_settings.webstats_js or ""
         except AttributeError:
-            return u""
+            return ""
 
     def update(self):
-        """ The viewlet manager _updateViewlets requires this method
-        """
+        """The viewlet manager _updateViewlets requires this method"""
         pass
