@@ -1,9 +1,9 @@
-# -*- coding: utf-8 -*-
 from .interfaces import IContextState
 from Acquisition import aq_base
 from Acquisition import aq_inner
 from Acquisition import aq_parent
 from plone.app.layout.navigation.interfaces import INavigationRoot
+from plone.base.utils import pretty_title_or_id
 from plone.memoize.view import memoize
 from plone.portlets.interfaces import ILocalPortletAssignable
 from plone.registry.interfaces import IRegistry
@@ -11,8 +11,7 @@ from Products.CMFCore.interfaces import IDynamicType
 from Products.CMFCore.interfaces import ISiteRoot
 from Products.CMFCore.utils import getToolByName
 from Products.CMFDynamicViewFTI.interfaces import IBrowserDefault
-from Products.CMFPlone import utils
-from Products.CMFPlone.interfaces import INonStructuralFolder
+from plone.base.interfaces import INonStructuralFolder
 from Products.Five.browser import BrowserView
 from zope.component import getMultiAdapter
 from zope.component import getUtility
@@ -30,8 +29,7 @@ BLACKLISTED_CATEGORIES = (
 
 @implementer(IContextState)
 class ContextState(BrowserView):
-    """Information about the state of the current context
-    """
+    """Information about the state of the current context"""
 
     @memoize
     def current_page_url(self):
@@ -144,7 +142,7 @@ class ContextState(BrowserView):
     @memoize
     def object_title(self):
         context = aq_inner(self.context)
-        return utils.pretty_title_or_id(context, context)
+        return pretty_title_or_id(context, context)
 
     @memoize
     def workflow_state(self):
@@ -236,10 +234,18 @@ class ContextState(BrowserView):
         ttool = getToolByName(context, "portal_types")
         actions = []
         actions.extend(
-            ttool.listActionInfos(object=context, category=category, max=max,)
+            ttool.listActionInfos(
+                object=context,
+                category=category,
+                max=max,
+            )
         )
         actions.extend(
-            atool.listActionInfos(object=context, categories=(category,), max=max,)
+            atool.listActionInfos(
+                object=context,
+                categories=(category,),
+                max=max,
+            )
         )
         return actions
 
