@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from plone.app.layout.navigation.interfaces import INavigationRoot
 from plone.app.layout.testing import INTEGRATION_TESTING
 from plone.app.testing import setRoles
@@ -6,7 +5,7 @@ from plone.app.testing import TEST_USER_ID
 from plone.app.testing.helpers import logout
 from plone.locking.interfaces import ILockable
 from Products.CMFDynamicViewFTI.interfaces import IBrowserDefault
-from Products.CMFPlone.interfaces import INonStructuralFolder
+from plone.base.interfaces import INonStructuralFolder
 from Products.CMFPlone.utils import _createObjectByType
 from zope.interface import alsoProvides
 from zope.interface import directlyProvides
@@ -15,8 +14,7 @@ import unittest
 
 
 class TestContextStateView(unittest.TestCase):
-    """Ensure that the basic redirector setup is successful.
-    """
+    """Ensure that the basic redirector setup is successful."""
 
     layer = INTEGRATION_TESTING
 
@@ -105,7 +103,7 @@ class TestContextStateView(unittest.TestCase):
         fti = self.portal.portal_types.TempFolder
         view_action = fti.getActionObject("object/view")
         view_perms = view_action.getPermissions()
-        view_action.edit(permissions=(u"Modify Portal Content",))
+        view_action.edit(permissions=("Modify Portal Content",))
 
         tf = _createObjectByType("TempFolder", self.folder, "tf")
         tf.manage_addLocalRoles(TEST_USER_ID, ("Manager",))
