@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from zope.interface import Attribute
 from zope.interface import Interface
 
@@ -12,13 +11,11 @@ optionflags = doctest.REPORT_ONLY_FIRST_FAILURE | doctest.ELLIPSIS
 
 
 class IZero(Interface):
-    """ Test interface zero
-    """
+    """Test interface zero"""
 
 
 class IOne(IZero):
-    """ Test interface one
-    """
+    """Test interface one"""
 
     one_name = Attribute("One name for IOne")
 
@@ -27,13 +24,12 @@ class IOne(IZero):
 
 
 class ITwo(Interface):
-    """ Test interface two
-    """
+    """Test interface two"""
 
     pass
 
 
-class NotAnInterface(object):
+class NotAnInterface:
     pass
 
 
