@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from plone.app.layout.navigation.interfaces import INavigationRoot
 from plone.app.layout.testing import INTEGRATION_TESTING
 from plone.app.testing import setRoles
@@ -6,7 +5,7 @@ from plone.app.testing import TEST_USER_ID
 from plone.app.testing.helpers import logout
 from plone.portlets.interfaces import IPortletType
 from plone.registry.interfaces import IRegistry
-from Products.CMFPlone.interfaces.controlpanel import ILinkSchema
+from plone.base.interfaces.controlpanel import ILinkSchema
 from zope.component import getUtility
 
 import os
@@ -184,3 +183,10 @@ class TestLayoutView(unittest.TestCase):
         settings.external_links_open_new_window = True
         body_class = view.bodyClass(template, view)
         self.assertTrue("pat-markspeciallinks" in body_class)
+
+    def testBodyClassColMarker(self):
+        context = self.portal["front-page"]
+        view = context.restrictedTraverse("view")
+        layout_view = context.restrictedTraverse("@@plone_layout")
+        body_class = layout_view.bodyClass(view, layout_view)
+        assert "col-content" in body_class
