@@ -1,9 +1,9 @@
-# -*- coding: utf-8 -*-
 from plone.app.contenttypes.testing import PLONE_APP_CONTENTTYPES_FIXTURE
 from plone.app.testing import FunctionalTesting
 from plone.app.testing import IntegrationTesting
 from plone.app.testing import PloneSandboxLayer
 from plone.app.testing import TEST_USER_ID
+from plone.app.testing import TEST_USER_PASSWORD
 from Products.CMFPlone.utils import _createObjectByType
 
 
@@ -29,8 +29,10 @@ class Fixture(PloneSandboxLayer):
 
 FIXTURE = Fixture()
 INTEGRATION_TESTING = IntegrationTesting(
-    bases=(FIXTURE,), name="plone.app.layout:Integration",
+    bases=(FIXTURE,),
+    name="plone.app.layout:Integration",
 )
 FUNCTIONAL_TESTING = FunctionalTesting(
-    bases=(FIXTURE,), name="plone.app.layout:Functional",
+    bases=(FIXTURE,),
+    name="plone.app.layout:Functional",
 )
