@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from AccessControl import getSecurityManager
 from Acquisition import aq_inner
 from DateTime import DateTime
@@ -8,7 +7,11 @@ from plone.app.layout.viewlets import ViewletBase
 from plone.app.multilingual.browser.vocabularies import translated_languages
 from plone.app.multilingual.interfaces import ITranslatable
 from plone.app.multilingual.interfaces import ITranslationManager
+from plone.base.interfaces import ISecuritySchema
+from plone.base.interfaces import ISiteSchema
+from plone.base.utils import base_hasattr
 from plone.memoize.instance import memoize
+from plone.memoize.view import memoize_contextless
 from plone.protect.authenticator import createToken
 from plone.registry.interfaces import IRegistry
 from Products.CMFCore.utils import _checkPermission
@@ -16,16 +19,14 @@ from Products.CMFCore.utils import getToolByName
 from Products.CMFCore.WorkflowCore import WorkflowException
 from Products.CMFEditions.Permissions import AccessPreviousVersions
 from Products.CMFPlone import PloneMessageFactory as _
-from Products.CMFPlone.interfaces import ISecuritySchema
-from Products.CMFPlone.interfaces import ISiteSchema
-from Products.CMFPlone.utils import base_hasattr
 from Products.CMFPlone.utils import log
 from Products.Five.browser import BrowserView
 from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
-from six.moves import range
+from urllib.parse import urlencode
 from zope.component import getMultiAdapter
 from zope.component import getUtility
 from zope.component import queryMultiAdapter
+from zope.deprecation import deprecation
 
 import logging
 import pkg_resources
@@ -49,10 +50,10 @@ class DocumentActionsViewlet(ViewletBase):
     index = ViewPageTemplateFile("document_actions.pt")
 
     def update(self):
-        super(DocumentActionsViewlet, self).update()
+        super().update()
 
         self.context_state = getMultiAdapter(
-            (self.context, self.request), name=u"plone_context_state"
+            (self.context, self.request), name="plone_context_state"
         )
         self.actions = self.context_state.actions("document_actions")
 
@@ -62,37 +63,85 @@ class DocumentBylineViewlet(ViewletBase):
     index = ViewPageTemplateFile("document_byline.pt")
 
     def update(self):
-        super(DocumentBylineViewlet, self).update()
-        self.context_state = getMultiAdapter(
-            (self.context, self.request), name=u"plone_context_state"
-        )
+        super().update()
         self.anonymous = self.portal_state.anonymous()
-        self.has_pam = HAS_PAM
+
+    @property
+    @deprecation.deprecate("The context_state property is unused and will be removed in Plone 7")
+    def context_state(self):
+        return getMultiAdapter((self.context, self.request), name="plone_context_state")
+
+    @property
+    @deprecation.deprecate("The has_pam property is unused and will be removed in Plone 7")
+    def has_pam(self):
+        return HAS_PAM
+
+    @property
+    @memoize_contextless
+    def portal_membership(self):
+        return getToolByName(self.context, "portal_membership")
 
     def show(self):
         registry = getUtility(IRegistry)
-        settings = registry.forInterface(ISecuritySchema, prefix="plone",)
+        settings = registry.forInterface(
+            ISiteSchema,
+            prefix="plone",
+        )
+        return not self.anonymous or settings.display_publication_date_in_byline
+
+    def show_about(self):
+        registry = getUtility(IRegistry)
+        settings = registry.forInterface(
+            ISecuritySchema,
+            prefix="plone",
+        )
         return not self.anonymous or settings.allow_anon_views_about
 
+    @deprecation.deprecate("The creator method is unused and will be removed in Plone 7")
     def creator(self):
         return self.context.Creator()
 
+    @deprecation.deprecate("The author method is unused and will be removed in Plone 7")
     def author(self):
         membership = getToolByName(self.context, "portal_membership")
         return membership.getMemberInfo(self.creator())
 
+    @deprecation.deprecate("The authorname method is unused and will be removed in Plone 7")
     def authorname(self):
         author = self.author()
         return author and author["fullname"] or self.creator()
 
+    @memoize
+    def get_member_info(self, user_id):
+        return self.portal_membership.getMemberInfo(user_id)
+
+    def get_url_path(self, user_id):
+        if self.get_member_info(user_id) is None:
+            return ""
+        if "/" in user_id:
+            qs = urlencode({"author": user_id})
+            return f"author/?{qs}"
+        return f"author/{user_id}"
+
+    def get_fullname(self, user_id):
+        info = self.get_member_info(user_id)
+        if info is None:
+            return user_id
+        return info.get("fullname") or user_id
+
+    def show_modification_date(self):
+        return not self.context.effective_date or (
+            self.context.effective_date.Date() < self.context.modification_date.Date()
+        )
+
     def isExpired(self):
         if base_hasattr(self.context, "expires"):
             return self.context.expires().isPast()
         return False
 
+    @deprecation.deprecate("The toLocalizedTime method is unused and will be removed in Plone 7")
     def toLocalizedTime(self, time, long_format=None, time_only=None):
-        """Convert time to localized time
-        """
+        """Convert time to localized time"""
         util = getToolByName(self.context, "translation_service")
         return util.ulocalized_time(
             time, long_format, time_only, self.context, domain="plonelocales"
@@ -118,6 +167,7 @@ class DocumentBylineViewlet(ViewletBase):
 
         return DateTime(date)
 
+    @deprecation.deprecate("The get_translations method is unused and will be removed in Plone 7")
     def get_translations(self):
         cts = []
         if ITranslatable.providedBy(self.context):
@@ -134,17 +184,17 @@ class DocumentBylineViewlet(ViewletBase):
 
 
 class HistoryByLineView(BrowserView):
-    """ DocumentByLine information for content history view """
+    """DocumentByLine information for content history view"""
 
     index = ViewPageTemplateFile("history_view.pt")
 
     def update(self):
         context = self.context
         self.portal_state = getMultiAdapter(
-            (context, self.request), name=u"plone_portal_state"
+            (context, self.request), name="plone_portal_state"
         )
         self.context_state = getMultiAdapter(
-            (self.context, self.request), name=u"plone_context_state"
+            (self.context, self.request), name="plone_context_state"
         )
         self.anonymous = self.portal_state.anonymous()
         self.has_pam = HAS_PAM
@@ -156,7 +206,10 @@ class HistoryByLineView(BrowserView):
 
     def show(self):
         registry = getUtility(IRegistry)
-        settings = registry.forInterface(ISecuritySchema, prefix="plone",)
+        settings = registry.forInterface(
+            ISecuritySchema,
+            prefix="plone",
+        )
         return not self.anonymous or settings.allow_anon_views_about
 
     def show_history(self):
@@ -212,8 +265,7 @@ class HistoryByLineView(BrowserView):
         return False
 
     def toLocalizedTime(self, time, long_format=None, time_only=None):
-        """Convert time to localized time
-        """
+        """Convert time to localized time"""
         util = getToolByName(self.context, "translation_service")
         return util.ulocalized_time(
             time, long_format, time_only, self.context, domain="plonelocales"
@@ -272,7 +324,7 @@ class ContentRelatedItems(ViewletBase):
             brains = catalog(UID=related)
             if brains:
                 # build a position dict by iterating over the items once
-                positions = dict([(v, i) for (i, v) in enumerate(related)])
+                positions = {v: i for (i, v) in enumerate(related)}
                 # We need to keep the ordering intact
                 res = list(brains)
 
@@ -328,7 +380,7 @@ class WorkflowHistoryViewlet(ViewletBase):
         if fullname:
             actor["fullname"] = fullname
 
-        return dict(actor=actor, actor_home="%s/author/%s" % (self.site_url, userid))
+        return dict(actor=actor, actor_home=f"{self.site_url}/author/{userid}")
 
     def workflowHistory(self, complete=True):
         """Return workflow history of this context.
@@ -357,7 +409,7 @@ class WorkflowHistoryViewlet(ViewletBase):
                 review_history = list(review_history)
 
             portal_type = context.portal_type
-            anon = _(u"label_anonymous_user", default=u"Anonymous User")
+            anon = _("label_anonymous_user", default="Anonymous User")
 
             for r in review_history:
                 r["type"] = "workflow"
@@ -421,8 +473,8 @@ class ContentHistoryViewlet(WorkflowHistoryViewlet):
             )
             info = dict(
                 type="versioning",
-                action=_(u"Edited"),
-                transition_title=_(u"Edited"),
+                action=_("Edited"),
+                transition_title=_("Edited"),
                 actorid=userid,
                 time=meta["timestamp"],
                 comments=meta["comment"],
@@ -431,14 +483,21 @@ class ContentHistoryViewlet(WorkflowHistoryViewlet):
             )
             if can_diff:
                 if version_id > 0:
-                    info["diff_previous_url"] = (
-                        "%s/@@history?one=%s&two=%s&_authenticator=%s"
-                        % (context_url, version_id, version_id - 1, token)
+                    info[
+                        "diff_previous_url"
+                    ] = "{}/@@history?one={}&two={}&_authenticator={}".format(
+                        context_url,
+                        version_id,
+                        version_id - 1,
+                        token,
                     )
                 if not rt.isUpToDate(context, version_id):
-                    info["diff_current_url"] = (
-                        "%s/@@history?one=current&two=%s&_authenticator=%s"
-                        % (context_url, version_id, token)
+                    info[
+                        "diff_current_url"
+                    ] = "{}/@@history?one=current&two={}&_authenticator={}".format(
+                        context_url,
+                        version_id,
+                        token,
                     )
             if can_revert:
                 info["revert_url"] = "%s/revertversion" % context_url
@@ -472,22 +531,16 @@ class ContentHistoryViewlet(WorkflowHistoryViewlet):
         return history
 
     def toLocalizedTime(self, time, long_format=None, time_only=None):
-        """Convert time to localized time
-        """
-        return DateTime(time).ISO()
-        # util = getToolByName(self.context, 'translation_service')
-        # return util.ulocalized_time(
-        #     time,
-        #     long_format,
-        #     time_only,
-        #     self.context,
-        #     domain='plonelocales'
-        # )
+        """Convert time to localized time"""
+        util = getToolByName(self.context, "translation_service")
+        return util.ulocalized_time(
+            time, long_format, time_only, self.context, domain="plonelocales"
+        )
 
 
 class ContentHistoryView(ContentHistoryViewlet):
     def __init__(self, context, request):
-        super(ContentHistoryView, self).__init__(context, request, None, None)
+        super().__init__(context, request, None, None)
         self.update()
 
     def __call__(self):
