@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from plone.app.layout.testing import FUNCTIONAL_TESTING
 from plone.testing import layered
 
@@ -17,7 +16,10 @@ def test_suite():
     suite.addTests(
         [
             layered(
-                doctest.DocFileSuite(test, optionflags=optionflags,),
+                doctest.DocFileSuite(
+                    test,
+                    optionflags=optionflags,
+                ),
                 layer=FUNCTIONAL_TESTING,
             )
             for test in normal_testfiles
