@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from plone.app.layout.viewlets.content import ContentHistoryViewlet
 from plone.app.layout.viewlets.content import WorkflowHistoryViewlet
 from plone.app.layout.viewlets.tests.base import ViewletsFunctionalTestCase
@@ -7,17 +6,18 @@ from plone.app.testing import logout
 from plone.app.testing import setRoles
 from plone.app.testing import TEST_USER_ID
 from plone.app.testing import TEST_USER_NAME
+from plone.app.testing import TEST_USER_PASSWORD
 
 
 class TestWorkflowHistoryViewlet(ViewletsFunctionalTestCase):
     def setUp(self):
-        super(TestWorkflowHistoryViewlet, self).setUp()
+        super().setUp()
         # add document, perform transition, set history for non-existent
         # member and also None (anonymous)
         self.folder.invokeFactory("Document", "d1")
 
     def addMember(self, username, roles=("Member",)):
-        self.portal.portal_membership.addMember(username, "secret", roles, [])
+        self.portal.portal_membership.addMember(username, TEST_USER_PASSWORD, roles, [])
 
     def delMember(self, username):
         self.portal.portal_membership.deleteMembers([username])
@@ -69,7 +69,7 @@ class TestWorkflowHistoryViewlet(ViewletsFunctionalTestCase):
 
 class TestContentHistoryViewlet(ViewletsFunctionalTestCase):
     def setUp(self):
-        super(TestContentHistoryViewlet, self).setUp()
+        super().setUp()
         # add document, perform transition, set history for non-existent
         # member and also None (anonymous)
         self.folder.invokeFactory("Document", "d1")
