@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from plone.app.layout.viewlets.social import SocialTagsViewlet
 from plone.app.layout.viewlets.tests.base import ViewletsTestCase
 from plone.app.testing import login
@@ -7,17 +6,16 @@ from plone.app.testing import setRoles
 from plone.app.testing import TEST_USER_ID
 from plone.app.testing import TEST_USER_NAME
 from plone.registry.interfaces import IRegistry
-from Products.CMFPlone.interfaces import ISocialMediaSchema
+from plone.base.interfaces import ISocialMediaSchema
 from zope.annotation.interfaces import IAnnotations
 from zope.component import getUtility
 
 
 class TestSocialViewlet(ViewletsTestCase):
-    """Test the content views viewlet.
-    """
+    """Test the content views viewlet."""
 
     def setUp(self):
-        super(TestSocialViewlet, self).setUp()
+        super().setUp()
         login(self.portal, TEST_USER_NAME)
         setRoles(self.portal, TEST_USER_ID, ["Manager"])
         self.folder.invokeFactory("News Item", "news-item", title="News Item")
@@ -92,13 +90,13 @@ class TestSocialViewlet(ViewletsTestCase):
         settings.share_social_data = False
         viewlet = SocialTagsViewlet(self.folder, self.app.REQUEST, None)
         viewlet.update()
-        self.assertEquals(len(viewlet.tags), 0)
+        self.assertEqual(len(viewlet.tags), 0)
 
     def testDisabledForLoggedUser(self):
         login(self.portal, TEST_USER_NAME)
         viewlet = SocialTagsViewlet(self.folder, self.app.REQUEST, None)
         viewlet.update()
-        self.assertEquals(len(viewlet.tags), 0)
+        self.assertEqual(len(viewlet.tags), 0)
         # clear cache to prevent memoize
         cache = IAnnotations(self.app.REQUEST)
         key = "plone.memoize"
@@ -133,12 +131,12 @@ class TestSocialViewlet(ViewletsTestCase):
         viewlet.update()
         self.assertTrue(
             self.tagFound(
-                viewlet, "property", "og:image", "http://nohost/plone/logo.png"
+                viewlet, "property", "og:image", "http://nohost/plone/++resource++plone-logo.svg"
             )
         )
         self.assertFalse(self.tagFound(viewlet, "itemprop"))
         self.assertTrue(
             self.bodyTagFound(
-                viewlet, "itemprop", "image", "http://nohost/plone/logo.png"
+                viewlet, "itemprop", "image", "http://nohost/plone/++resource++plone-logo.svg"
             )
         )
